@@ -16,7 +16,8 @@ function(pca, title = "no title provided", ...) {
 	cumvariance <- variance  # temporary definition as a vector of proper length
 	for (n in c(1:length(variance))) {cumvariance[n] <- sum(variance[1:n])}
 
-	title <- paste(title, ": Scores by PC", sep = "")
+#	title <- paste(title, ": Scores by PC", sep = "")
+	title <- bquote(bold(.(eval(title)) ~':'~Scores~by~PC))
 
 	plot(rep(1:10, each = nrow(pca$x)), as.vector(pca$x[,1:10]), type = "p",
 		col = "red", main = title, xlab = "component", ylab = "scores",
